@@ -1,16 +1,16 @@
 /* Copyright (C) 2008 The goocanvasmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -23,10 +23,10 @@ int
 main(int argc, char* argv[])
 {
 
-  Gtk::Main app(&argc, &argv) ;
-  Goocanvas::init("goocanvasmm Simple Example", "0.1", argc, argv) ;
+  Gtk::Main app(&argc, &argv);
+  Goocanvas::init();
 
   DemoWindow sw ;
-  Gtk::Main::run(sw) ;
+  Gtk::Main::run(sw);
 }
 
