@@ -21,7 +21,7 @@ int
 main(int argc, char* argv[])
 {
   Gtk::Main app(&argc, &argv);
-  Goocanvas::init("goocanvasmm Simple Example", "0.1", argc, argv);
+  Goocanvas::init();
 
   Window w ;
   Gtk::Main::run(w);
