@@ -22,8 +22,8 @@
 int
 main(int argc, char* argv[])
 {
-  Gtk::Main app(&argc, &argv) ;
-  Goocanvas::init("goocanvasmm Simple Example", "0.1", argc, argv);
+  Gtk::Main app(&argc, &argv);
+  Goocanvas::init();
 
   Glib::RefPtr<Goocanvas::Table> table = Goocanvas::Table::create();
 
